emacs-orgmode@gnu.org archives
 help / color / mirror / code / Atom feed
* [PATCH] Correct some docstrings [part 3]
@ 2010-07-16 16:22 Phil Rooke
  2010-07-16 18:56 ` Patchwork: Patch 140 Accepted Carsten Dominik
  0 siblings, 1 reply; 2+ messages in thread
From: Phil Rooke @ 2010-07-16 16:22 UTC (permalink / raw)
  To: emacs-orgmode

This is the third patch in a series that makes some straightforward
corrections to a number of docstrings.  Each change is normally to:

- correct a typo, or
- fix up hyperlinks to function or variable names, or
- ensure slightly better conformance with the documentation guidelines
  and tips given in the Elisp manual

No attempt is made to provide missing docstrings or document arguments.

Cheers,

Phil

-- 

 lisp/org-icalendar.el  |    7 +++++--
 lisp/org-id.el         |    2 ++
 lisp/org-indent.el     |   16 ++++++++++------
 lisp/org-inlinetask.el |    7 +++----
 lisp/org-jsinfo.el     |    6 +++---
 lisp/org-latex.el      |   10 +++++-----
 lisp/org-list.el       |   10 +++++-----
 7 files changed, 33 insertions(+), 25 deletions(-)

diff --git a/lisp/org-icalendar.el b/lisp/org-icalendar.el
index a50fdb6..2a506a3 100644
--- a/lisp/org-icalendar.el
+++ b/lisp/org-icalendar.el
@@ -26,7 +26,10 @@
 ;;
 ;;; Commentary:
 
+;;; Code:
+
 (require 'org-exp)
+
 (eval-when-compile
   (require 'cl))
 
@@ -164,7 +167,7 @@ The iCalendar standard requires that all entries have a unique identifier.
 Org will create these identifiers as needed.  When this variable is non-nil,
 the created UIDs will be stored in the ID property of the entry.  Then the
 next time this entry is exported, it will be exported with the same UID,
-superceding the previous form of it.  This is essential for
+superseding the previous form of it.  This is essential for
 synchronization services.
 This variable is not turned on by default because we want to avoid creating
 a property drawer in every entry if people are only playing with this feature,
@@ -192,7 +195,7 @@ file, but with extension `.ics'."
 
 ;;;###autoload
 (defun org-export-icalendar-all-agenda-files ()
-  "Export all files in `org-agenda-files' to iCalendar .ics files.
+  "Export all files in the variable `org-agenda-files' to iCalendar .ics files.
 Each iCalendar file will be located in the same directory as the Org-mode
 file, but with extension `.ics'."
   (interactive)
diff --git a/lisp/org-id.el b/lisp/org-id.el
index cf61f8a..1f795ab 100644
--- a/lisp/org-id.el
+++ b/lisp/org-id.el
@@ -69,6 +69,8 @@
 ;;        Find the location of an entry with specific id.
 ;;
 
+;;; Code:
+
 (require 'org)
 
 (declare-function message-make-fqdn "message" ())
diff --git a/lisp/org-indent.el b/lisp/org-indent.el
index 48b10b7..233871e 100644
--- a/lisp/org-indent.el
+++ b/lisp/org-indent.el
@@ -29,22 +29,24 @@
 ;; by adding text properties to a buffer to make sure lines are
 ;; indented according to outline structure.
 
+;;; Code:
+
 (require 'org-macs)
 (require 'org-compat)
 (require 'org)
+
 (eval-when-compile
   (require 'cl))
 
-
 (defgroup org-indent nil
   "Options concerning dynamic virtual outline indentation."
   :tag "Org Indent"
   :group 'org)
 
 (defconst org-indent-max 40
-  "Maximum indentation in characters")
+  "Maximum indentation in characters.")
 (defconst org-indent-max-levels 40
-  "Maximum indentation in characters")
+  "Maximum indentation in characters.")
 
 (defvar org-indent-strings nil
   "Vector with all indentation strings.
@@ -53,7 +55,7 @@ It will be set in `org-indent-initialize'.")
   "Vector with all indentation star strings.
 It will be set in `org-indent-initialize'.")
 (defvar org-hide-leading-stars-before-indent-mode nil
-  "Used locally")
+  "Used locally.")
 
 (defcustom org-indent-boundary-char ?\   ; comment to protect space char
   "The end of the virtual indentation strings, a single-character string.
@@ -67,13 +69,15 @@ it may be prettier to customize the org-indent face."
   :type 'character)
 
 (defcustom org-indent-mode-turns-off-org-adapt-indentation t
-  "Non-nil means turning on `org-indent-mode' turns off indentation adaptation.
+  "Non-nil means setting the variable `org-indent-mode' will \
+turn off indentation adaptation.
 For details see the variable `org-adapt-indentation'."
   :group 'org-indent
   :type 'boolean)
 
 (defcustom org-indent-mode-turns-on-hiding-stars t
-  "Non-nil means turning on `org-indent-mode' turns on `org-hide-leading-stars'."
+  "Non-nil means setting the variable `org-indent-mode' will \
+turn on `org-hide-leading-stars'."
   :group 'org-indent
   :type 'boolean)
 
diff --git a/lisp/org-inlinetask.el b/lisp/org-inlinetask.el
index ea7a63a..5ca8d78 100644
--- a/lisp/org-inlinetask.el
+++ b/lisp/org-inlinetask.el
@@ -33,7 +33,7 @@
 ;; and properties.  However, these nodes are treated specially by the
 ;; visibility cycling and export commands.
 ;;
-;; Visibility cycling exempts these nodes from cycling. So whenever their
+;; Visibility cycling exempts these nodes from cycling.  So whenever their
 ;; parent is opened, so are these tasks.  This will only work with
 ;; `org-cycle', so if you are also using other commands to show/hide
 ;; entries, you will occasionally find these tasks to behave like
@@ -74,8 +74,7 @@
 ;;
 ;; C-c C-x t      Insert a new inline task with END line
 
-
-;;; Code
+;;; Code:
 
 (require 'org)
 
@@ -116,7 +115,7 @@ default, or nil of no state should be assigned."
 
 (defun org-inlinetask-insert-task (&optional no-state)
   "Insert an inline task.
-If prefix arg NO-STATE is set, irgnore `org-inlinetask-defaut-state'."
+If prefix arg NO-STATE is set, ignore `org-inlinetask-defaut-state'."
   (interactive "P")
   (or (bolp) (newline))
   (let ((indent org-inlinetask-min-level))
diff --git a/lisp/org-latex.el b/lisp/org-latex.el
index b6a7769..c971a69 100644
--- a/lisp/org-latex.el
+++ b/lisp/org-latex.el
@@ -400,7 +400,7 @@ hurt if it is present."
 
 (defcustom org-export-latex-remove-from-headlines
   '(:todo nil :priority nil :tags nil)
-  "A plist of keywords to remove from headlines. OBSOLETE.
+  "A plist of keywords to remove from headlines.  OBSOLETE.
 Non-nil means remove this keyword type from the headline.
 
 Don't remove the keys, just change their values.
@@ -432,7 +432,7 @@ allowed.  The default we use here encompasses both."
   :type '(repeat (string :tag "Extension")))
 
 (defcustom org-export-latex-coding-system nil
-  "Coding system for the exported LaTex file."
+  "Coding system for the exported LaTeX file."
   :group 'org-export-latex
   :type 'coding-system)
 
@@ -656,7 +656,7 @@ when PUB-DIR is set, use this as the publishing directory."
 			  (org-entry-get rbeg "EXPORT_FILE_NAME" t))
 		     (file-name-nondirectory ;sans-extension
 		      (or buffer-file-name
-			  (error "Don't know which export file to use.")))))
+			  (error "Don't know which export file to use")))))
 		".tex")))
 	 (filename
 	  (and filename
@@ -1136,7 +1136,7 @@ LEVEL indicates the default depth for export."
 
 (defvar org-export-latex-format-toc-function
   'org-export-latex-format-toc-default
-  "The function formatting returning the string to createthe table of contents.
+  "The function formatting returning the string to create the table of contents.
 The function mus take one parameter, the depth of the table of contents.")
 
 (defun org-export-latex-make-header (title opt-plist)
@@ -2190,7 +2190,7 @@ The conversion is made depending of STRING-BEFORE and STRING-AFTER."
        (replace-match "")))))
 
 (defun org-export-latex-fix-inputenc ()
-  "Set the codingsystem in inputenc to what the buffer is."
+  "Set the coding system in inputenc to what the buffer is."
   (let* ((cs buffer-file-coding-system)
 	 (opt (or (ignore-errors (latexenc-coding-system-to-inputenc cs))
 		  "utf8")))
diff --git a/lisp/org-list.el b/lisp/org-list.el
index 4e4306e..50891f0 100644
--- a/lisp/org-list.el
+++ b/lisp/org-list.el
@@ -624,7 +624,7 @@ If the cursor is not in an item, throw an error."
 
 (defun org-end-of-item-text-before-children ()
   "Move to the end of the item text, stops before the first child if any.
-Assumes that the cursor is in the first ine of an item."
+Assumes that the cursor is in the first line of an item."
   (goto-char
    (min (save-excursion (org-end-of-item) (point))
 	(save-excursion
@@ -1019,7 +1019,7 @@ I.e. to the text after the last item."
 
 (defun org-outdent-item-tree (arg &optional no-subtree)
   "Outdent a local list item including its children.
-If NO-SUBTREE is set, only outdend the item itself, not its children."
+If NO-SUBTREE is set, only outdent the item itself, not its children."
   (interactive "p")
   (org-indent-item-tree (- arg) no-subtree))
 
@@ -1386,7 +1386,7 @@ Valid parameters PARAMS are
 
 (defun org-list-to-latex (list &optional params)
   "Convert LIST into a LaTeX list.
-LIST is as returnd by `org-list-parse-list'.  PARAMS is a property list
+LIST is as returned by `org-list-parse-list'.  PARAMS is a property list
 with overruling parameters for `org-list-to-generic'."
   (org-list-to-generic
    list
@@ -1403,7 +1403,7 @@ with overruling parameters for `org-list-to-generic'."
 
 (defun org-list-to-html (list &optional params)
   "Convert LIST into a HTML list.
-LIST is as returnd by `org-list-parse-list'.  PARAMS is a property list
+LIST is as returned by `org-list-parse-list'.  PARAMS is a property list
 with overruling parameters for `org-list-to-generic'."
   (org-list-to-generic
    list
@@ -1420,7 +1420,7 @@ with overruling parameters for `org-list-to-generic'."
 
 (defun org-list-to-texinfo (list &optional params)
   "Convert LIST into a Texinfo list.
-LIST is as returnd by `org-list-parse-list'.  PARAMS is a property list
+LIST is as returned by `org-list-parse-list'.  PARAMS is a property list
 with overruling parameters for `org-list-to-generic'."
   (org-list-to-generic
    list

^ permalink raw reply related	[flat|nested] 2+ messages in thread

* Patchwork: Patch 140 Accepted
  2010-07-16 16:22 [PATCH] Correct some docstrings [part 3] Phil Rooke
@ 2010-07-16 18:56 ` Carsten Dominik
  0 siblings, 0 replies; 2+ messages in thread
From: Carsten Dominik @ 2010-07-16 18:56 UTC (permalink / raw)
  To: emacs-orgmode

Patch 140 (http://patchwork.newartisans.com/patch/140/) is now Accepted.

This relates to the following submission:

http://mid.gmane.org/%3Cm2iq4f8kie.fsf%40bo.yax.org.uk%3E

^ permalink raw reply	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2010-07-16 18:56 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2010-07-16 16:22 [PATCH] Correct some docstrings [part 3] Phil Rooke
2010-07-16 18:56 ` Patchwork: Patch 140 Accepted Carsten Dominik

Code repositories for project(s) associated with this public inbox

	https://git.savannah.gnu.org/cgit/emacs/org-mode.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).
diff --git a/lisp/org-jsinfo.el b/lisp/org-jsinfo.el
index 264896c..ffda475 100644
--- a/lisp/org-jsinfo.el
+++ b/lisp/org-jsinfo.el
@@ -26,12 +26,12 @@
 ;;
 ;;; Commentary:
 
 ;; This file implements the support for Sebastian Rose's Javascript
 ;; org-info.js to display an org-mode file exported to HTML in an
 ;; Info-like way, or using folding similar to the outline structure
 ;; org org-mode itself.
 
-;; Documentation for using this module is in the Org manual. The script
+;; Documentation for using this module is in the Org manual.  The script
 ;; itself is documented by Sebastian Rose in a file distributed with
 ;; the script.  FIXME: Accurate pointers!
 
@@ -87,7 +87,7 @@ line in the buffer.  See also the variable `org-infojs-options'."
 (defcustom org-infojs-options
   (mapcar (lambda (x) (cons (car x) (nth 2 x)))
 	  org-infojs-opts-table)
-  "Options settings for the INFOJS Javascript.
+  "Options settings for the INFOJS JavaScript.
 Each of the options must have an entry in `org-export-html/infojs-opts-table'.
 The value can either be a string that will be passed to the script, or
 a property.  This property is then assumed to be a property that is defined
@@ -26,12 +26,12 @@
 ;;; Commentary:
 
-;; This file implements the support for Sebastian Rose's Javascript
+;; This file implements the support for Sebastian Rose's JavaScript
 ;; org-info.js to display an org-mode file exported to HTML in an
 ;; Info-like way, or using folding similar to the outline structure